@@ -215,6 +215,22 @@ def update_object_by_key(objectName, key='id', keyValue=1, fields=None):
         query = f'UPDATE neuralplatform_{objectName.lower()} SET {changes} WHERE {key} {operator} {keyValue};'
         run_update(query)
 
+def exists_object(objectName, conditions):
+    parsed_conditions = ""
+    for key in conditions:
+        operator = '='
+        value = conditions[key]
+        if isinstance(value, list):
+            operator = 'IN'
+            value = '(' + str(value)[1:-1] + ')'
+        elif isinstance(value, str):
+            value = '"' + value + '"'
+        parsed_conditions += f'{key} {operator} {value} AND '
+    else:
+        parsed_conditions = parsed_conditions[:-4]
+    query = f'SELECT * FROM neuralplatform_{objectName.lower()} WHERE {parsed_conditions};'
+    return run_exists(query)
+
 def get_projects_of_projectManager(projectManager_id):
 	query = f"SELECT project_id FROM neuralplatform_projectmanagerassignedproject WHERE projectManager_id = {projectManager_id};"
 	project_ids = run_select(query)
@@ -317,6 +333,12 @@ def classify_page(page_id, class_id):
     run_insert(f"INSERT INTO neuralplatform_classification(classDefinition_id, page_id) VALUES ({class_id}, {page_id});")
     update_object_by_key('page', 'id', page_id, {'tagged': True})
 
+def classify_productionPage(productionPage_id, class_id):
+    if run_exists(f"SELECT DISTINCT 1 FROM neuralplatform_productionclassification WHERE productionPage_id = {productionPage_id};"):
+        run_delete(f"DELETE FROM neuralplatform_productionclassification WHERE productionPage_id = {productionPage_id};")
+    run_insert(f"INSERT INTO neuralplatform_productionclassification(classDefinition_id, productionPage_id) VALUES ({class_id}, {productionPage_id});")
+    update_object_by_key('productionPage', 'id', productionPage_id, {'tagged': True})
+
 def insert_manualStep(result, request_id):
     query = f"INSERT INTO neuralplatform_manualstep(status, result, request_id) " + \
             f"VALUES ('pending', '{json.dumps(result)}', {request_id});"
